@@ -1,6 +1,3 @@
-from pyinspect.exceptions import install, print_exception
-
-install()
-
+from pyinspect.exceptions import install_traceback, print_exception
 from pyinspect.utils import print_function
 from pyinspect.find import search
